@@ -38,5 +38,5 @@ from ._geometry import (calc_line,
                         point_to_vector_distance)
 
 
-from ._smooth import moving_average, movav
+from ._smooth import moving_average, movav, movstd
 from ..operators import *
